;;; Blocks --- a theme for Sawmill
;;; (C) 2000 Paul J Collins
;;; Distributed under the terms of the GNU General Public 
;;; License, version 2 or (at your option) later

;;; There are no frame definitions for shaped windows yet.

(let*
    ;; Colours & pixmaps
    ((inactive-background (get-color "grey30"))
     (inactive-background-lighter (get-color "grey40"))
     (inactive-foreground (get-color "black"))
     (active-background (get-color "SlateBlue3"))
     (title-background (get-color "SlateBlue4"))
     (title-foreground (get-color "white"))
     ;; Frame part backgrounds
     (title-part-bg (list inactive-background title-background nil nil))
     (corner-part-bg (list inactive-background-lighter active-background nil nil))
     (border-part-bg (list inactive-background-lighter active-background nil nil))
     (menu-button-bg (list inactive-background title-foreground nil inactive-foreground))
     (close-box-bg (list (make-image "close-icon-inactive.png")
			 (make-image "close-icon.png")
			 nil nil))
     ;; Frame definitions
     (normal-frame `(((class . title)
		      (foreground . ,title-foreground)
		      (background . ,title-part-bg)
;		      (font . ,(font-name default-font))
		      (text . ,window-name)
		      (height . 18)
		      (left-edge . -3)
		      (top-edge . -18)
		      (right-edge . -3)
		      (y-justify . center)
		      (x-justify . 18))
		     ((class . menu-button)
		      (background . ,menu-button-bg)
		      (width . 6)
		      (height . 6)
		      (left-edge . 3)
		      (top-edge . -12))
		     ((class . close-button) ; a purple square
		      (background . ,title-part-bg)
		      (width . 16)
		      (height . 16)
		      (top-edge . -17)
		      (right-edge . -2))
		     ((class . close-button) ; the white X
		      (background . ,close-box-bg)
		      (width . 16)
		      (height . 16)
		      (top-edge . -17)
		      (right-edge . -2))
		     ;;The following duplicated pairs of corner pieces
		     ;;are due to the bugs in 0.25.1.  The will be
		     ;;changed back as soon as it is fixed.
		     ((class . bottom-left-corner)
		      (background . ,border-part-bg)
		      (below-client . t)
		      (bottom-edge . -3)
		      (left-edge . -3)
		      (width . 3)
		      (height . 16))
		     ((class . bottom-left-corner)
		      (background . ,border-part-bg)
		      (below-client . t)
		      (bottom-edge . -3)
		      (left-edge . 0)
		      (width . 13)
		      (height . 3))
 		     ((class . bottom-right-corner)
		      (background . ,border-part-bg)
		      (below-client . t)
		      (bottom-edge . -3)
		      (right-edge . -3)
		      (width . 3)
		      (height . 16))
		     ((class . bottom-right-corner)
		      (background . ,border-part-bg)
		      (below-client . t)
		      (bottom-edge . -3)
		      (right-edge . 0)
		      (width . 13)
		      (height . 3))
		     ((class . top-left-corner)
		      (background . ,border-part-bg)
		      (below-client . t)
		      (top-edge . -20)
		      (left-edge . -5)
		      (width . 18)
		      (height . 20))
		     ((class . top-right-corner)
		      (background . ,border-part-bg)
		      (below-client . t)
		      (top-edge . -20)
		      (right-edge . -5)
		      (width . 18)
		      (height . 20))
		     ((class . bottom-border)
		      (background . ,border-part-bg)
		      (below-client . t)
		      (height . 3)
		      (bottom-edge . -3)
		      (left-edge . 11)
		      (right-edge . 11))
		     ((class . left-border)
		      (background . ,border-part-bg)
		      (below-client . t)
		      (width . 3)
		      (top-edge . 0)
		      (bottom-edge . 11)
		      (left-edge . -3))
		     ((class . right-border)
		      (background . ,border-part-bg)
		      (below-client . t)
		      (width . 3)
		      (top-edge . 0)
		      (bottom-edge . 11)
		      (right-edge . -3))))
     (transient-frame `(((class . title)
			 (foreground . ,title-foreground)
			 (background . ,title-part-bg)
;			 (font . ,(font-name default-font))
			 (text . ,window-name)
			 (height . 18)
			 (left-edge . 0)
			 (right-edge . 0)
			 (top-edge . -18)
			 (y-justify . center)
			 (x-justify . 18))
			((class . menu-button)
			 (background . ,menu-button-bg)
			 (width . 6)
			 (height . 6)
			 (left-edge . 6)
			 (top-edge . -12))
			((class . close-button) ; a purple square
			 (background . ,title-part-bg)
			 (width . 16)
			 (height . 16)
			 (top-edge . -17)
			 (right-edge . 2))
			((class . close-button)
			 (background . ,close-box-bg)
			 (width . 16)
			 (height . 16)
			 (right-edge . 2)
			 (top-edge . -17))
			((class . bottom-right-corner)
			 (background . ,border-part-bg)
			 (below-client . t)
			 (bottom-edge . -2)
			 (right-edge . -2)
			 (width . 2)
			 (height . 16))
			((class . bottom-right-corner)
			 (background . ,border-part-bg)
			 (below-client . t)
			 (bottom-edge . -2)
			 (right-edge . 0)
			 (width . 14)
			 (height . 2))))
     (shaped-frame `(((class . title)
		      (foreground . ,title-foreground)
		      (background . ,title-part-bg)
;		      (font . ,(font-name default-font))
		      (text . ,window-name)
		      (height . 18)
		      (left-edge . 0)
		      (right-edge . 0)
		      (top-edge . -18)
		      (y-justify . center)
		      (x-justify . 18))
		     ((class . menu-button)
		      (background . ,menu-button-bg)
		      (width . 6)
		      (height . 6)
		      (left-edge . 6)
		      (top-edge . -12))
		     ((class . close-button) ; a purple square
		      (background . ,title-part-bg)
		      (width . 16)
		      (height . 16)
		      (top-edge . -17)
		      (right-edge . 2))
		     ((class . close-button)
		      (background . ,close-box-bg)
		      (width . 16)
		      (height . 16)
		      (right-edge . 2)
		      (top-edge . -17)))))
  
  (add-frame-style 'Blocks
		   (lambda (w type)
		     (cond ((eq type 'shaped)
			    shaped-frame)
			   ((eq type 'transient)
			    transient-frame)
			   ((eq type 'shaped-transient)
			    nil-frame)
			   ((eq type 'unframed)
			    nil-frame)
			   (t
			    normal-frame)))))


		   

